tsseg.algorithms.tirex package
==============================

.. warning:: Under development.

Bridge module re-exporting TiRex-based segmenters from sibling ``tsseg-tirex``
project. Exposes multiple detector classes (Hidden/Cosine/L2 × CPD/State/Cluster).

| **Type:** change point detection, state detection and clustering
| **Requires:** ``tsseg-tirex``

**Implementation:** Re-export from ``tsseg-tirex``.

Submodules
----------

tsseg.algorithms.tirex.detector module
--------------------------------------

.. automodule:: tsseg.algorithms.tirex.detector
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.tirex
   :members:
   :show-inheritance:
   :undoc-members:
